@@ -19,6 +19,7 @@
 
 */
 
+#include <QApplication>
 #include <QAbstractTableModel>
 #include <QDate>
 #include <QFile>
@@ -32,12 +33,10 @@
 #include <QDomDocument>
 #include <QDomElement>
 
-#include <kapplication.h>
 #include <kiconloader.h>
 #include <KLocalizedString>
-#include <knotification.h>
+#include <KNotification>
 #include <ksgrd/SensorManager.h>
-#include <kdebug.h>
 #include "StyleEngine.h"
 
 #include "SensorLoggerDlg.h"
@@ -637,7 +636,7 @@ void SensorLogger::contextMenuRequest( const QModelIndex &index, const QPoint &p
       break;
     case 2: {
       KSGRD::SensorDisplay::DeleteEvent *ev = new KSGRD::SensorDisplay::DeleteEvent( this );
-      kapp->postEvent(parent(), ev);
+      qApp->postEvent(parent(), ev);
       break;
       }
     case 3:
